@@ -21,7 +21,7 @@ class Browser(ABC):
 
     @classmethod
     @abstractmethod
-    async def create_browser(cls, **kwargs):
+    async def create(cls, **kwargs):
         """
         Create and launch the browser instance (async factory method).
 
@@ -29,7 +29,7 @@ class Browser(ABC):
             Browser instance
 
         Example:
-            >>> browser = await PlaywrightBrowser.create_browser(headless=True)
+            >>> browser = await PlaywrightBrowser.create(headless=True)
         """
         pass
 
@@ -42,7 +42,7 @@ class Browser(ABC):
             Session instance
 
         Example:
-            >>> browser = await PlaywrightBrowser.create_browser()
+            >>> browser = await PlaywrightBrowser.create()
             >>> session = await browser.create_session()
         """
         pass
