@@ -1,8 +1,8 @@
 """Playwright session implementation."""
 
-from typing import TYPE_CHECKING, Optional, List
+from typing import TYPE_CHECKING
 from playwright.async_api import BrowserContext
-from ....browser import Session, Cookie
+from ....browser import Session
 
 if TYPE_CHECKING:
     from .playwright_page import PlaywrightPage
@@ -13,17 +13,17 @@ class PlaywrightSession(Session):
     Playwright implementation of Session.
 
     Wraps Playwright's BrowserContext for session management.
+    Users should set cookies directly on the BrowserContext before passing it in.
     """
 
-    def __init__(self, context: BrowserContext, cookies: Optional[List[Cookie]] = None):
+    def __init__(self, context: BrowserContext):
         """
-        Initialize PlaywrightSession (use create_session factory instead).
+        Initialize PlaywrightSession.
 
         Args:
             context: Playwright BrowserContext instance
-            cookies: Optional list of cookies for this session
         """
-        super().__init__(cookies=cookies)
+        super().__init__()
         self._context = context
 
     async def create_page(self) -> "PlaywrightPage":
